message property
String
get
message
The location associated with the error. The message to be displayed for this error. The message should indicate what is wrong with the code and why it is wrong.
Implementation
//Location location;
/// The message to be displayed for this error. The message should indicate
/// what is wrong with the code and why it is wrong.
String get message;